

|LASSO| Python Library
======================

This python library is designed for general purpose usage in the field of
Computer Aided Engineering (CAE) and contains a small fraction of the
`LASSO GmbH`_ codebase. 

Module Overview:
 - `lasso.ansa`_
 - `lasso.dyna`_
 - `lasso.diffcrash`_

 For further infos please read the Documentation_.

.. _LASSO GmbH: https://www.lasso.de/en
.. _Documentation: https://lasso-gmbh.github.io/lasso-python/build/html/index.html
.. _lasso.ansa: https://lasso-gmbh.github.io/lasso-python/build/html/ansa/ansa.html
.. _lasso.dyna: https://lasso-gmbh.github.io/lasso-python/build/html/dyna/dyna.html
.. _lasso.diffcrash: https://lasso-gmbh.github.io/lasso-python/build/html/diffcrash/diffcrash.html

Contact
-------

**You like our work?** Contact Us:

    |HOME| `Website`_

    |MAIL| `Mail`_

    |LINKEDIN| `LinkedIn`_

Discussions on: 

    |DISCORD| `Discord`_
 
.. _Mail: lasso@lasso.de
.. _LinkedIn: https://www.linkedin.com/company/lasso-gmbh
.. _Website:  https://www.lasso.de/en
.. _Discord:  https://discord.gg/GeHu79b

.. |LASSO| image:: ./images/lasso-logo.png
    :target: https://www.lasso.de/en
.. |MAIL| image:: images/icon-mail.png 
    :target: lasso@lasso.de
.. |LINKEDIN| image:: images/icon-linkedin.png 
    :target: https://www.linkedin.com/company/lasso-gmbh
.. |HOME| image:: images/icon-home.png 
    :target: https://www.lasso.de/en
.. |DISCORD| image:: images/icon-discord.png
    :target: https://discord.gg/GeHu79b


Installation
------------

:: 

    python -m pip install lasso-python

FAQ
---

**What does LASSO do?**

    We are a high-end CAE company focusing on:
      - highly-complex structural mechanics
      - software engineering
      - machine learning and artificial intelligence
      - distribution and support of BETA CAE Systems products
      - manufacturing technology 

**Why sharing code as a company?** 

    Because the little things don't hurt us and CAE is already a harsh field.
    We will not get anywhere alone. Please take this as motivation to share 
    the small things and to help others make life easier.

**Can I use your software in my company**

    Yes, you can use it without any concerns. For further info 
    regarding redistribution please read the license file or contact
    us.

